@@ -93,17 +93,6 @@ extern "C" {
 	extern gboolean xkl_config_registry_load(XklConfigRegistry *
 						 config);
 
-/**
- * xkl_config_registry_set_custom_charset
- * @config: the config registry
- *
- * Sets custom charset. This charset (if specified) overrides the local 
- * user charset used for description strings in XklConfigItems
- */
-	extern void
-	 xkl_config_registry_set_custom_charset(XklConfigRegistry *
-						config,
-						const gchar * charset);
 /**
  * ConfigItemProcessFunc:
  * @config: the config registry
