@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2002-2006 Sergey V. Udaltsov <svu@gnome.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #ifndef __XKLAVIER_PRIVATE_H__
 #define __XKLAVIER_PRIVATE_H__
 
@@ -98,6 +117,13 @@ struct _XklEnginePrivate {
 	 */
 	const gchar **(*get_groups_names) (XklEngine * engine);
 
+	/*
+	 * Get the list of the indicators names
+	 * xkb: return cached list of the indicators names
+	 * xmodmap: return NULL
+	 */
+	const gchar **(*get_indicators_names) (XklEngine * engine);
+
 	/*
 	 * Get the maximum number of loaded groups
 	 * xkb: returns 1 or XkbNumKbdGroups
@@ -222,8 +248,6 @@ struct _XklConfigRegistryPrivate {
 	xmlDocPtr doc;
 
 	xmlXPathContextPtr xpath_context;
-
-	const gchar *custom_charset;
 };
 
 extern void xkl_engine_ensure_vtable_inited(XklEngine * engine);
@@ -247,7 +271,7 @@ extern void xkl_engine_process_state_modification(XklEngine * engine,
 
 extern Window xkl_engine_get_registered_parent(XklEngine * engine,
 					       Window win);
-extern void xkl_engine_reset_all_info(XklEngine * engine,
+extern void xkl_engine_reset_all_info(XklEngine * engine, gboolean force,
 				      const gchar reason[]);
 extern gboolean xkl_engine_load_window_tree(XklEngine * engine);
 extern gboolean xkl_engine_load_subtree(XklEngine * engine, Window window,
@@ -312,10 +336,6 @@ extern void xkl_engine_try_call_state_func(XklEngine * engine,
 					   change_type,
 					   XklState * old_state);
 
-extern void xkl_i18n_init(void);
-
-extern gint xkl_get_language_priority(const gchar * language);
-
 extern gchar *xkl_engine_get_ruleset_name(XklEngine * engine,
 					  const gchar default_ruleset[]);
 
@@ -376,6 +396,10 @@ extern void xkl_config_registry_free(XklConfigRegistry * config);
 extern gchar *xkl_locale_from_utf8(XklConfigRegistry * config,
 				   const gchar * utf8string);
 
+extern gboolean xkl_config_registry_load_helper(XklConfigRegistry * config,
+					 const char default_ruleset[],
+					 const char base_dir[]);
+
 #define XKLAVIER_STATE_PROP_LENGTH 2
 
 /* taken from XFree86 maprules.c */
