@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2002-2006 Sergey V. Udaltsov <svu@gnome.org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <time.h>
 #include <string.h>
 
@@ -27,6 +46,10 @@ xkl_engine_get_window_title(XklEngine * engine, Window w)
 	unsigned long nitems, rest;
 	unsigned char *prop;
 
+	if ((w == xkl_engine_priv(engine, root_window))
+	    || (w == PointerRoot))
+		return g_strdup("ROOT");
+
 	if (Success ==
 	    XGetWindowProperty(xkl_engine_get_display(engine), w,
 			       xkl_engine_priv(engine, atoms)[WM_NAME], 0L,
